@@ -1,4 +1,5 @@
 int var_tlsp_tls_ask_ccert;
+int var_smtpd_hide_client_session;
 int var_psc_enforce_tls;
 int var_psc_disable_vrfy;
 int var_threaded_bounce;
@@ -7,9 +8,11 @@ int var_tlsp_tls_set_sessid;
 int var_tlsp_tls_req_ccert;
 int var_tlsp_enforce_tls;
 int var_tlsp_use_tls;
+int var_smtp_tlsrpt_skip_reused_hs;
 int var_tlsp_clnt_use_tls;
 int var_tlsp_tls_enable_rpk;
 int var_append_dot_mydomain;
+int var_smtp_tlsrpt_enable;
 int var_psc_helo_required;
 int var_relay_before_rcpt_checks;
 int var_smtpd_req_deadline;
